@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2007 Sun Microsystems Inc.
+# Copyright 2007-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,15 +14,15 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Displays a GUI for the user to set Orca application-specific preferences."""
 
-__id__        = "$Id:$"
-__version__   = "$Revision:$"
-__date__      = "$Date:$"
-__copyright__ = "Copyright (c) 2007 Sun Microsystems Inc."
+__id__        = "$Id: app_gui_prefs.py 4352 2008-11-19 16:34:28Z wwalker $"
+__version__   = "$Revision: 4352 $"
+__date__      = "$Date: 2008-11-19 11:34:28 -0500 (Wed, 19 Nov 2008) $"
+__copyright__ = "Copyright (c) 2007-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import gtk
@@ -86,7 +86,13 @@ class OrcaSetupGUI(orca_gui_prefs.OrcaSetupGUI):
         #
         self.appScript = thisAppScript
 
-        self.get_widget("notebook").remove_page(0)
+        # Don't remove the page because this tickles some strange bug
+        # in gail or gtk+ (see bug #554002).  Instead, we'll just hide it.
+        #
+        # self.get_widget("notebook").remove_page(0)
+        generalTab = self.get_widget("notebook").get_children()[0]
+        generalTab.hide()
+
         self.get_widget("speechSystemsLabel").set_sensitive(False)
         self.get_widget("speechSystems").set_sensitive(False)
         self.get_widget("speechServersLabel").set_sensitive(False)
@@ -94,7 +100,7 @@ class OrcaSetupGUI(orca_gui_prefs.OrcaSetupGUI):
 
         vbox = self.appScript.getAppPreferencesGUI()
         if vbox:
-            label = gtk.Label(orca_state.locusOfFocus.getApplication().name)
+            label = gtk.Label(orca_state.activeScript.app.name)
             self.get_widget("notebook").append_page(vbox, label)
 
     def _createPronunciationTreeView(self, pronunciations=None):
@@ -118,7 +124,7 @@ class OrcaSetupGUI(orca_gui_prefs.OrcaSetupGUI):
         # Adjust the title of the app-specific Orca Preferences dialog to
         # include the name of the application.
         #
-        self.app = orca_state.locusOfFocus.getApplication()
+        self.app = orca_state.activeScript.app
         self.applicationName = self.app.name 
         title = _("Orca Preferences for %s") % self.applicationName
         self.get_widget("orcaSetupWindow").set_title(title)
@@ -135,6 +141,21 @@ class OrcaSetupGUI(orca_gui_prefs.OrcaSetupGUI):
         ftp = focus_tracking_presenter.FocusTrackingPresenter()
         ftp.loadAppSettings(self.appScript)
 
+    def _getAppNameForAttribute(self, attributeName):
+        """Converts the given Atk attribute name into the application's
+        equivalent. This is necessary because an application or toolkit
+        (e.g. Gecko) might invent entirely new names for the same text
+        attributes.
+
+        Arguments:
+        - attribName: The name of the text attribute
+
+        Returns the application's equivalent name if found or attribName
+        otherwise.
+        """
+
+        return self.appScript.getAppNameForAttribute(attributeName)
+
     def _markModified(self):
         """ Mark as modified the user application specific custom key bindings:
         """
@@ -294,7 +315,7 @@ def showPreferencesUI():
 
     # The name of the application that currently has focus.
     #
-    applicationName = orca_state.locusOfFocus.getApplication().name
+    applicationName = orca_state.activeScript.app.name
 
     removeGeneralPane = False
     if not orca_state.appOS and not orca_state.orcaOS:
