@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py 4447 2009-01-21 19:55:29Z wwalker $"
-__version__   = "$Revision: 4447 $"
-__date__      = "$Date: 2009-01-21 14:55:29 -0500 (Wed, 21 Jan 2009) $"
+__id__        = "$Id: braillegenerator.py 4277 2008-10-05 21:46:30Z wwalker $"
+__version__   = "$Revision: 4277 $"
+__date__      = "$Date: 2008-10-05 17:46:30 -0400 (Sun, 05 Oct 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1085,8 +1085,7 @@ class BrailleGenerator:
         componentRegion = braille.Component(
             obj, text,
             indicator=settings.brailleRadioButtonIndicators[ \
-            int(state.contains(pyatspi.STATE_CHECKED) \
-                or state.contains(pyatspi.STATE_PRESSED))])
+            int(state.contains(pyatspi.STATE_CHECKED))])
         regions.append(componentRegion)
 
         return [regions, componentRegion]
@@ -1386,8 +1385,7 @@ class BrailleGenerator:
             image = None
         if (not displayedText or len(displayedText) == 0) and image:
             if image.imageDescription:
-                regions[0].append(braille.Component(obj,
-                                  image.imageDescription))
+                regions[0].append(image.imageDescription)
             [cellRegions, focusRegion] = self._getBrailleRegionsForImage(obj)
             regions[0].extend(cellRegions)
 
