@@ -19,9 +19,9 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py 4452 2009-01-22 00:34:51Z wwalker $"
-__version__   = "$Revision: 4452 $"
-__date__      = "$Date: 2009-01-21 19:34:51 -0500 (Wed, 21 Jan 2009) $"
+__id__        = "$Id: gnomespeechfactory.py 4336 2008-11-17 18:15:32Z wwalker $"
+__version__   = "$Revision: 4336 $"
+__date__      = "$Date: 2008-11-17 13:15:32 -0500 (Mon, 17 Nov 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -705,10 +705,7 @@ class SpeechServer(speechserver.SpeechServer):
                      used to augment/override the default
                      voice settings.
         """
-        chname = chnames.getCharacterName(character)
-        if orca_state.activeScript and orca_state.usePronunciationDictionary:
-            chname = orca_state.activeScript.adjustForPronunciation(chname)
-        self.speak(chname, acss)
+        self.speak(chnames.getCharacterName(character), acss)
 
     def speakUtterances(self, utterances, acss=None, interrupt=True):
         """Speaks the given list of utterances immediately.
