@@ -23,9 +23,9 @@ implementation in Gecko:
 http://developer.mozilla.org/en/docs/Accessibility/ATSPI_Support
 """
 
-__id__        = "$Id: speech_generator.py 4221 2008-09-15 08:11:23Z wwalker $"
-__version__   = "$Revision: 4221 $"
-__date__      = "$Date: 2008-09-15 04:11:23 -0400 (Mon, 15 Sep 2008) $"
+__id__        = "$Id: speech_generator.py 4399 2009-01-02 21:02:45Z joanied $"
+__version__   = "$Revision: 4399 $"
+__date__      = "$Date: 2009-01-02 21:02:45 +0000 (Fri, 02 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -653,12 +653,17 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
 
         # Skip items of unknown rolenames, menu bars, labels with 
         # children, and autocompletes.  (With autocompletes, we
-        # wind up speaking the text object)
+        # wind up speaking the text object). Beginning with Firefox
+        # 3.2, list items have names corresponding with their text.
+        # This results in getDisplayedText returning actual text
+        # and the parent list item being spoken when it should not
+        # be. So we'll take list items out of the context.
         #
         skipRoles = [pyatspi.ROLE_UNKNOWN,
                      pyatspi.ROLE_MENU_BAR,
                      pyatspi.ROLE_LABEL,
-                     pyatspi.ROLE_AUTOCOMPLETE]
+                     pyatspi.ROLE_AUTOCOMPLETE,
+                     pyatspi.ROLE_LIST_ITEM]
 
         # Stop if we get to a document frame or an internal frame.
         #
@@ -693,12 +698,21 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
             # Also skip the parent if its accessible text is a single 
             # EMBEDDED_OBJECT_CHARACTER: Script.getDisplayedText will
             # end up coming back to the child of an object for the text
-            # if an object's text contains a single EOC.
+            # if an object's text contains a single EOC. In addition,
+            # beginning with Firefox 3.2, a table cell may derive its
+            # accessible name from focusable objects it contains (e.g.
+            # links, form fields). getDisplayedText will return the
+            # object's name in this case (because of the presence of
+            # the EOC and other characters). This causes us to be
+            # chatty. So if it's a table cell which contains an EOC,
+            # we will also skip the parent.
             #
             parentText = self._script.queryNonEmptyText(parent)
             if parentText:
                 unicodeText = parentText.getText(0, -1).decode("UTF-8")
-                if unicodeText == self._script.EMBEDDED_OBJECT_CHARACTER:
+                if self._script.EMBEDDED_OBJECT_CHARACTER in unicodeText \
+                   and (len(unicodeText) == 1 \
+                        or role == pyatspi.ROLE_TABLE_CELL):
                     parent = parent.parent
                     continue
 
